@@ -284,6 +284,70 @@ panel.superpose <-
 
 
 
+
+
+
+
+panel.superpose.2 <- 
+    function (x, y, subscripts, groups, col, col.line = superpose.line$col,
+              col.symbol = superpose.symbol$col, pch = superpose.symbol$pch,
+              cex = superpose.symbol$cex, lty = superpose.line$lty,
+              lwd = superpose.line$lwd, type="p", ...)
+{
+    
+    ##   `panel.superpose.2' :  This is a version of the 'panel.superpose'
+    ##   Trellis panel function that allows the plot `type' to change between
+    ##   superimposed (overlayed) data sets.  See the `panel.xyplot' function
+    ##   for details on the `type' option which is usually a single character,
+    ##   but here is a character vector with each element specifying the
+    ##   plot style of each subsequently-overlayed plot.
+    ##                        ---  Neil Klepeis, 26-Dec-2001
+    
+    if (length(x) > 0) {
+        if (!missing(col)) {
+            if (missing(col.line))
+                col.line <- col
+            if (missing(col.symbol))
+                col.symbol <- col
+        }
+        superpose.symbol <- trellis.par.get("superpose.symbol")
+        superpose.line <- trellis.par.get("superpose.line")
+        x <- as.numeric(x)
+        y <- as.numeric(y)
+        vals <- sort(unique(groups))
+        nvals <- length(vals)
+        col.line <- rep(col.line, length = nvals)
+        col.symbol <- rep(col.symbol, length = nvals)
+        pch <- rep(pch, length = nvals)
+        lty <- rep(lty, length = nvals)
+        lwd <- rep(lwd, length = nvals)
+        cex <- rep(cex, length = nvals)
+        type <- rep(type, length = nvals)      # new line here
+        for (i in seq(along = vals)) {
+            id <- (groups[subscripts] == vals[i])
+            if (any(id))
+                panel.xyplot(x = x[id], y = y[id], pch = pch[i],
+                  cex = cex[i], col.line = col.line[i], col.symbol = col.symbol[i],
+                  lty = lty[i], lwd = lwd[i], type=type[i], ...)
+        }
+    }
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 panel.mathdensity <-
     function(dmath = dnorm,
              args = list(mean = 0, sd = 1),
